@@ -1,4 +1,4 @@
 #!/usr/bin/env bash
-export PYTHONPATH=$PWD/Assets/site_packages
+export PYTHONPATH=$PWD/Assets/site-packages
 echo $PYTHONPATH
 python3 Assets/SEIR_model.py
\ No newline at end of file
