@@ -1,6 +1,6 @@
-from typing import List
+from typing import List, Dict
 
-from click.testing import CliRunner
+from click.testing import CliRunner, Result
 
 
 def get_subcommands_from_help_result(result):
@@ -19,21 +19,23 @@ def striped_cli_output_lines(result):
     return list(filter(lambda x: len(x), map(str.strip, result.output.split('\n'))))
 
 
-def invoke_command(*args, start_command=None):
+def invoke_command(*args, start_command=None, mix_stderr: bool = True, env: Dict[str, str] = None):
+    if env is None:
+        env = dict()
     if start_command is None:
         start_command = []
     from idmtools_cli.main import start
     from idmtools_cli.cli.entrypoint import cli
     start()
-    runner = CliRunner()
+    runner = CliRunner(mix_stderr=mix_stderr, env=env)
     final_command = start_command + list(args) if len(args) else start_command
-    result = runner.invoke(cli, final_command)
+    result = runner.invoke(cli, final_command, env=env)
     return result
 
 
-def run_command(*args: List[str], start_command: List[str] = None, base_command: str = None) -> object:
+def run_command(*args: str, start_command: List[str] = None, base_command: str = None, mix_stderr: bool = True, env: Dict[str, str] = None) -> Result:
     if start_command is None:
         start_command = []
     if base_command:
         start_command.append(base_command)
-    return invoke_command(*args, start_command=start_command)
+    return invoke_command(*args, start_command=start_command, mix_stderr=mix_stderr, env=env)
