@@ -7,13 +7,14 @@ from dataclasses import field, dataclass
 from functools import partial
 from logging import getLogger, DEBUG
 from threading import Lock
-from typing import Any, List, Type, Dict, Union, TYPE_CHECKING, Optional
-from uuid import UUID, uuid4
+from pathlib import Path
+from typing import Any, List, Type, Dict, TYPE_CHECKING, Optional
 from idmtools.assets import Asset, AssetCollection
 from idmtools.core import EntityStatus, ItemType
+from idmtools.core import IDMTOOLS_USER_HOME
 from idmtools.entities.experiment import Experiment
 from idmtools.entities.iplatform_ops.iplatform_experiment_operations import IPlatformExperimentOperations
-from idmtools.utils.file import file_contents_to_generator
+from idmtools.utils.file import file_content_to_generator
 from idmtools.utils.json import IDMJSONEncoder
 
 if TYPE_CHECKING:  # pragma: no cover
@@ -35,25 +36,31 @@ class TestExecutePlatformExperimentOperation(IPlatformExperimentOperations):
     platform_type: Type = field(default=ExperimentDict)
     experiments: Dict[str, Experiment] = field(default_factory=dict, compare=False, metadata={"pickle_ignore": True})
 
-    def get(self, experiment_id: Union[str, UUID], **kwargs) -> Any:
+    def get(self, experiment_id: str, **kwargs) -> Any:
         exp_path = self.get_experiment_path(experiment_id)
-        path = os.path.join(exp_path, "experiment.json")
-        if not os.path.exists(path):
+        experiment_path = os.path.join(exp_path, "experiment.json")
+        if not os.path.exists(experiment_path):
             logger.error(f"Cannot find experiment with id {experiment_id}")
             raise FileNotFoundError(f"Cannot find experiment with id {experiment_id}")
 
-        logger.info(f"Loading experiment metadata from {path}")
-        with open(path, 'r') as metadata_in:
+        simulation_metadata_path = os.path.join(exp_path, "simulation_index.json")
+        if not os.path.exists(simulation_metadata_path):
+            logger.error(f"Cannot find simulation index for experiment with id {experiment_id}")
+            raise FileNotFoundError(f"Cannot find simulation index for experiment with id {experiment_id}")
+
+        logger.info(f"Loading experiment metadata from {experiment_path}")
+        with open(experiment_path, 'r') as metadata_in:
             metadata = json.load(metadata_in)
-            return ExperimentDict(metadata)
+        logger.info(f"Loading simulation metadata from {simulation_metadata_path}")
+        with open(simulation_metadata_path, 'r') as metadata_in:
+            metadata['simulations'] = json.load(metadata_in)
+        return ExperimentDict(metadata)
 
     def platform_create(self, experiment: Experiment, **kwargs) -> Any:
         if logger.isEnabledFor(DEBUG):
             logger.debug('Creating Experiment')
-        uid = uuid4()
-        experiment.uid = uid
         EXPERIMENTS_LOCK.acquire()
-        self.experiments[uid] = experiment
+        self.experiments[experiment.uid] = experiment
         EXPERIMENTS_LOCK.release()
         logger.debug(f"Created Experiment {experiment.uid}")
         self.send_assets(experiment, **kwargs)
@@ -84,7 +91,7 @@ class TestExecutePlatformExperimentOperation(IPlatformExperimentOperations):
             if sim.status in [None, EntityStatus.CREATED]:
                 self.platform._simulations.run_item(sim)
 
-    def get_experiment_path(self, experiment_id: Union[UUID, str]) -> str:
+    def get_experiment_path(self, experiment_id: str) -> str:
         """
         Get path to experiment directory
 
@@ -192,6 +199,7 @@ class TestExecutePlatformExperimentOperation(IPlatformExperimentOperations):
         excluded = ['platform_id', 'item_type', 'frozen', 'simulations']
         experiment = Experiment(**{k: v for k, v in data.items() if k not in excluded})
         experiment.platform_metadata = data
+        experiment.task_type = data['tags']['task_type']
         if data['assets']:
             assets = AssetCollection()
             exp_path = os.path.join(self.get_experiment_path(experiment.uid), "Assets")
@@ -199,7 +207,7 @@ class TestExecutePlatformExperimentOperation(IPlatformExperimentOperations):
                 for file in files:
                     fp = os.path.abspath(os.path.join(root, file))
                     asset = Asset(absolute_path=fp, filename=file)
-                    asset.download_generator_hook = partial(file_contents_to_generator, fp)
+                    asset.download_generator_hook = partial(file_content_to_generator, fp)
                     assets.add_asset(asset)
             experiment.assets = assets
         if children:
@@ -219,3 +227,11 @@ class TestExecutePlatformExperimentOperation(IPlatformExperimentOperations):
         EXPERIMENTS_LOCK.release()
         self.send_assets(experiment)
         return experiment
+
+    def post_run_item(self, experiment: Experiment, **kwargs):
+        exp_path = self.get_experiment_path(experiment.uid)
+        sim_path = Path(exp_path, "simulation_index.json")
+        with open(sim_path, "w") as f:
+            json.dump([s.id for s in experiment.simulations], f)
+
+        super().post_run_item(experiment, **kwargs)
