@@ -8,9 +8,9 @@ import sys
 from dataclasses import dataclass
 from functools import partial
 from logging import getLogger
+from pathlib import Path
 from threading import Lock
 from typing import List, Dict, Any, Type, TYPE_CHECKING, Optional
-from uuid import UUID, uuid4
 from idmtools.assets import Asset, AssetCollection
 from idmtools.core import EntityStatus
 from idmtools.core.task_factory import TaskFactory
@@ -19,7 +19,7 @@ from idmtools.entities.command_task import CommandTask
 from idmtools.entities.experiment import Experiment
 from idmtools.entities.iplatform_ops.iplatform_simulation_operations import IPlatformSimulationOperations
 from idmtools.entities.simulation import Simulation
-from idmtools.utils.file import file_contents_to_generator
+from idmtools.utils.file import file_content_to_generator
 from idmtools.utils.json import IDMJSONEncoder
 
 if TYPE_CHECKING:  # pragma: no cover
@@ -36,7 +36,7 @@ class SimulationDict(dict):
     pass
 
 
-def run_simulation(simulation_id: Simulation, command: str, parent_uid: UUID, execute_directory, shell: bool = False):
+def run_simulation(simulation_id: Simulation, command: str, parent_uid: str, execute_directory, shell: bool = False):
     simulation_path = os.path.join(execute_directory, str(parent_uid), str(simulation_id))
     os.makedirs(simulation_path, exist_ok=True)
     with open(os.path.join(simulation_path, "StdOut.txt"), "w") as out, \
@@ -96,7 +96,7 @@ class TestExecutePlatformSimulationOperation(IPlatformSimulationOperations):
     platform: 'TestExecutePlatform'
     platform_type: Type = SimulationDict
 
-    def get(self, simulation_id: UUID, experiment_id: UUID = None, **kwargs) -> Any:
+    def get(self, simulation_id: str, experiment_id: str = None, **kwargs) -> Any:
         if simulation_id and experiment_id:
             exp_path = os.path.join(self.platform.execute_directory, str(experiment_id))
             sim_path = os.path.join(exp_path, str(simulation_id))
@@ -111,7 +111,6 @@ class TestExecutePlatformSimulationOperation(IPlatformSimulationOperations):
     def platform_create(self, simulation: Simulation, **kwargs) -> Simulation:
         simulation.platform = self
         experiment_id = simulation.parent_id
-        simulation.uid = uuid4()
         self.save_metadata(simulation)
         return simulation
 
@@ -123,7 +122,6 @@ class TestExecutePlatformSimulationOperation(IPlatformSimulationOperations):
             if simulation.status is None:
                 self.pre_create(simulation, **kwargs)
                 experiment_id = simulation.parent_id
-                simulation.uid = uuid4()
                 self.save_metadata(simulation)
                 self.post_create(simulation, **kwargs)
                 simulations.append(simulation)
@@ -221,11 +219,11 @@ class TestExecutePlatformSimulationOperation(IPlatformSimulationOperations):
 
         """
         for asset in simulation.parent.assets:
-            remote_path = os.path.join(exp_path, asset.relative_path) if asset.relative_path else exp_path
-            sim_assets = os.path.join(sim_path, "Assets")
-            src_path = os.path.join(remote_path, asset.filename)
-            dest_path = os.path.join(sim_assets, asset.filename)
-            os.makedirs(sim_assets, exist_ok=True)
+            remote_path = Path(exp_path).joinpath(asset.relative_path) if asset.relative_path else Path(exp_path)
+            sim_assets = Path(sim_path).joinpath("Assets")
+            src_path = remote_path.joinpath(asset.filename)
+            dest_path = sim_assets.joinpath(asset.filename)
+            sim_assets.mkdir(parents=True, exist_ok=True)
             if sys.platform in ['win32']:
                 import win32file
                 link_worked = True
@@ -296,7 +294,7 @@ class TestExecutePlatformSimulationOperation(IPlatformSimulationOperations):
             for file in files:
                 fp = os.path.abspath(os.path.join(root, file))
                 asset = Asset(absolute_path=fp, filename=file)
-                asset.download_generator_hook = partial(file_contents_to_generator, fp)
+                asset.download_generator_hook = partial(file_content_to_generator, fp)
                 cksum_hash = hashlib.md5()
                 with open(fp, 'rb') as fin:
                     cksum_hash.update(fin.read())
@@ -308,8 +306,6 @@ class TestExecutePlatformSimulationOperation(IPlatformSimulationOperations):
                   **kwargs) -> Simulation:
         # convert the dictionary to simulation
         sim: Simulation = Simulation(**{k: v for k, v in dict_sim.items() if k not in ['platform_id', 'item_type']})
-        # str to uid
-        sim._uid = UUID(sim._uid)
         try:
             # load status from str
             sim.status = EntityStatus[sim.status.upper()]
@@ -336,14 +332,14 @@ class TestExecutePlatformSimulationOperation(IPlatformSimulationOperations):
                         dict_asset['absolute_path'] = os.path.join(sim_path, dict_asset['filename'])
                 asset = Asset(**dict_asset)
                 asset.persisted = True
-                asset.download_generator_hook = partial(file_contents_to_generator, asset.absolute_path)
+                asset.download_generator_hook = partial(file_content_to_generator, asset.absolute_path)
                 ac.add_asset(asset)
             sim.assets = ac
         # should we fully load the task?
         if load_task:
-            if dict_sim['tags'] and 'task_type' in dict_sim['tags']:
+            if parent.task_type:
                 try:
-                    sim.task = TaskFactory().create(dict_sim['tags']['task_type'], **dict_sim['task'])
+                    sim.task = TaskFactory().create(parent.task_type, **dict_sim['task'])
                 except Exception as e:
                     logger.exception(e)
 
