@@ -1,5 +1,4 @@
 from operator import itemgetter
-
 from COMPS.Data import Experiment as COMPSExperiment, QueryCriteria
 
 
@@ -16,13 +15,11 @@ def validate_output(self, exp_id, expected_sim_count):
     self.assertEqual(sim_count, expected_sim_count)
 
 
-def validate_sim_tags(self, exp_id, expected_tags, task_type):
+def validate_sim_tags(self, exp_id, expected_tags):
     tags = []
     for simulation in COMPSExperiment.get(exp_id).get_simulations():
         tags.append(simulation.get(simulation.id, QueryCriteria().select_children('tags')).tags)
 
     sorted_tags = sorted(tags, key=itemgetter('a'))
-    for tag_list in expected_tags:
-        tag_list['task_type'] = task_type
     sorted_expected_tags = sorted(expected_tags, key=itemgetter('a'))
     self.assertEqual(sorted_tags, sorted_expected_tags)
